==> streams-node-empty-0.0.7.tgz: package/lib/index.js <==
/**
* @license Apache-2.0
*
* Copyright (c) 2018 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

/**
* Create an "empty" readable stream.
*
* @module @stdlib/streams-node-empty
*
* @example
* var inspectStream = require( '@stdlib/streams-node-inspect-sink' );
* var emptyStream = require( '@stdlib/streams-node-empty' );
*
* function log( chunk ) {
*    console.log( chunk.toString() );
* }
*
* var stream = emptyStream();
*
* stream.pipe( inspectStream( log ) );
*
* @example
* var emptyStream = require( '@stdlib/streams-node-empty' );
*
* var opts = {
*     'objectMode': false
* };
*
* var createStream = emptyStream.factory( opts );
*
* // Create 10 identically configured streams...
* var streams = [];
* var i;
* for ( i = 0; i < 10; i++ ) {
*     streams.push( createStream() );
* }
*
* @example
* var inspectStream = require( '@stdlib/streams-node-inspect-sink' );
* var emptyStream = require( '@stdlib/streams-node-empty' );
*
* function log( v ) {
*    console.log( v );
* }
*
* var stream = emptyStream.objectMode();
*
* stream.pipe( inspectStream.objectMode( log ) );
*/


// MODULES //

var setReadOnly = require( '@stdlib/utils-define-nonenumerable-read-only-property' );
var stream = require( './main.js' );
var objectMode = require( './object_mode.js' );
var factory = require( './factory.js' );


// MAIN //

setReadOnly( stream, 'objectMode', objectMode );
setReadOnly( stream, 'factory', factory );


// EXPORTS //

module.exports = stream;

==> streams-node-empty-0.1.0.tgz: package/lib/index.js <==
/**
* @license Apache-2.0
*
* Copyright (c) 2018 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

/**
* Create an "empty" readable stream.
*
* @module @stdlib/streams-node-empty
*
* @example
* var inspectStream = require( '@stdlib/streams-node-inspect-sink' );
* var emptyStream = require( '@stdlib/streams-node-empty' );
*
* function log( chunk ) {
*    console.log( chunk.toString() );
* }
*
* var stream = emptyStream();
*
* stream.pipe( inspectStream( log ) );
*
* @example
* var emptyStream = require( '@stdlib/streams-node-empty' );
*
* var opts = {
*     'objectMode': false
* };
*
* var createStream = emptyStream.factory( opts );
*
* // Create 10 identically configured streams...
* var streams = [];
* var i;
* for ( i = 0; i < 10; i++ ) {
*     streams.push( createStream() );
* }
*
* @example
* var inspectStream = require( '@stdlib/streams-node-inspect-sink' );
* var emptyStream = require( '@stdlib/streams-node-empty' );
*
* function log( v ) {
*    console.log( v );
* }
*
* var stream = emptyStream.objectMode();
*
* stream.pipe( inspectStream.objectMode( log ) );
*/


// MODULES //

var setReadOnly = require( '@stdlib/utils-define-nonenumerable-read-only-property' );
var main = require( './main.js' );
var objectMode = require( './object_mode.js' );
var factory = require( './factory.js' );


// MAIN //

setReadOnly( main, 'objectMode', objectMode );
setReadOnly( main, 'factory', factory );


// EXPORTS //

module.exports = main;
